-
public interface OpenFeatureStatus
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public classOpenFeatureStatus.NotReadyThe provider has not been initialized and cannot yet evaluate flags.
public classOpenFeatureStatus.ReadyThe provider is ready to resolve flags.
public final classOpenFeatureStatus.ErrorThe provider is in an error state and unable to evaluate flags.
public final classOpenFeatureStatus.FatalThe provider has entered an irrecoverable error state.
public classOpenFeatureStatus.StaleThe provider's cached state is no longer valid and may not be up-to-date with the source of truth.
public classOpenFeatureStatus.ReconcilingThe provider is reconciling its state with a context change.
-