-
- All Implemented Interfaces:
-
dev.openfeature.sdk.OpenFeatureStatus
public final class OpenFeatureStatus.Error implements OpenFeatureStatus
The provider is in an error state and unable to evaluate flags.
-
-
Field Summary
Fields Modifier and Type Field Description private final OpenFeatureErrorerror
-
Constructor Summary
Constructors Constructor Description OpenFeatureStatus.Error(OpenFeatureError error)
-
Method Summary
Modifier and Type Method Description final OpenFeatureErrorgetError()-
-
Constructor Detail
-
OpenFeatureStatus.Error
OpenFeatureStatus.Error(OpenFeatureError error)
-
-
Method Detail
-
getError
final OpenFeatureError getError()
-
-
-
-