Package 

Interface Tracking


  • 
    public interface Tracking
    
                        

    Interface for Tracking events.

    • Method Summary

      Modifier and Type Method Description
      abstract Unit track(String trackingEventName, TrackingEventDetails details) Performs tracking of a particular action or application state.
      • Methods inherited from class java.lang.Object

        clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
    • Method Detail

      • track

         abstract Unit track(String trackingEventName, TrackingEventDetails details)

        Performs tracking of a particular action or application state.

        Parameters:
        trackingEventName - Event name to track
        details - Data pertinent to a particular tracking event